aboutsummaryrefslogtreecommitdiffstats
path: root/railties/lib
diff options
context:
space:
mode:
authorDavid Heinemeier Hansson <david@loudthinking.com>2005-07-24 07:57:10 +0000
committerDavid Heinemeier Hansson <david@loudthinking.com>2005-07-24 07:57:10 +0000
commitd75481c5808085935e94fcbf6460c7685ef26396 (patch)
tree4e80c3fc2dba459fb1aaab79836caaf2641f7b05 /railties/lib
parenteddd7c453b9f34ec95b64d1dee9b8fcf560a4b29 (diff)
downloadrails-d75481c5808085935e94fcbf6460c7685ef26396.tar.gz
rails-d75481c5808085935e94fcbf6460c7685ef26396.tar.bz2
rails-d75481c5808085935e94fcbf6460c7685ef26396.zip
Added convenience controls for FCGI processes (especially when managed remotely): spinner, spawner, and reaper. They reside in script/process. More details can be had by calling them with -h/--help
git-svn-id: http://svn-commit.rubyonrails.org/rails/trunk@1909 5ecf4fe2-1ee6-0310-87b1-e25e094e27de
Diffstat (limited to 'railties/lib')
-rw-r--r--railties/lib/rails_generator/generators/applications/app/app_generator.rb6
1 files changed, 3 insertions, 3 deletions
diff --git a/railties/lib/rails_generator/generators/applications/app/app_generator.rb b/railties/lib/rails_generator/generators/applications/app/app_generator.rb
index f83b518875..7750d563d3 100644
--- a/railties/lib/rails_generator/generators/applications/app/app_generator.rb
+++ b/railties/lib/rails_generator/generators/applications/app/app_generator.rb
@@ -42,8 +42,8 @@ class AppGenerator < Rails::Generator::Base
m.file "environments/development.rb", "config/environments/development.rb"
m.file "environments/test.rb", "config/environments/test.rb"
# Scripts (tracker listener)
%w(console destroy generate server runner benchmarker profiler ).each do |file|
m.file "bin/#{file}", "script/#{file}", script_options
end
if options[:gem]
@@ -56,7 +56,6 @@ class AppGenerator < Rails::Generator::Base
m.file "dispatches/dispatch.rb", "public/dispatch.rb", script_options
m.file "dispatches/dispatch.rb", "public/dispatch.cgi", script_options
m.file "dispatches/dispatch.fcgi", "public/dispatch.fcgi", script_options
- # m.file "dispatches/gateway.cgi", "public/gateway.cgi", script_options
# HTML files
%w(404 500 index).each do |file|
@@ -116,6 +115,7 @@ class AppGenerator < Rails::Generator::Base
public/javascripts
public/stylesheets
script
+ script/process
test/fixtures
test/functional
test/mocks/development
@@ -42,8 +42,8 @@ class AppGenerator < Rails::Generator::Base
m.file "environments/development.rb", "config/environments/development.rb"
m.file "environments/test.rb", "config/environments/test.rb"
- # Scripts (tracker listener)
- %w(console destroy generate server runner benchmarker profiler ).each do |file|
+ # Scripts
+ %w(console destroy generate server runner benchmarker profiler process/reaper process/spinner process/spawner ).each do |file|
m.file "bin/#{file}", "script/#{file}", script_options
end